@@ -1,8 +1,10 @@
 package DB::SimpleKV;
 
+
 use 5.006;
 use strict;
 use warnings;
+use Fcntl ':flock';
 
 =head1 NAME
 
@@ -10,11 +12,11 @@ DB::SimpleKV - Simple k/v interface to text configuration file
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub new {
   my $class = shift;
@@ -73,10 +75,12 @@ sub save {
   my $self = shift;
 
   open my $dbx, ">", $self->{file} or die $!;
+  flock($dbx, LOCK_EX) or die $!;
+
   for (sort keys %{$self->{hash}} ) {
     print $dbx $_,'=',$self->{hash}->{$_},"\n";
   }
-  close $dbx;
+  close $dbx or die $!;
 }
 
 
